The boards in this folder are not working or for debugging purposes
only. These are placed in this folder, so they won't be automatically 
compiled. Use theses drivers at own risk.

.. warning ::
    The drivers in this folder can be modified or removed between versions
    without prior warning.